aboutsummaryrefslogtreecommitdiffstats
path: root/server/src/main/java/com/vaadin/ui/Table.java
diff options
context:
space:
mode:
Diffstat (limited to 'server/src/main/java/com/vaadin/ui/Table.java')
-rw-r--r--server/src/main/java/com/vaadin/ui/Table.java23
1 files changed, 12 insertions, 11 deletions
diff --git a/server/src/main/java/com/vaadin/ui/Table.java b/server/src/main/java/com/vaadin/ui/Table.java
index f518f4f161..4e85b9e028 100644
--- a/server/src/main/java/com/vaadin/ui/Table.java
+++ b/server/src/main/java/com/vaadin/ui/Table.java
@@ -57,6 +57,7 @@ import com.vaadin.event.dd.DragSource;
import com.vaadin.event.dd.DropHandler;
import com.vaadin.event.dd.DropTarget;
import com.vaadin.event.dd.acceptcriteria.ServerSideCriterion;
+import com.vaadin.legacy.ui.LegacyField;
import com.vaadin.server.KeyMapper;
import com.vaadin.server.LegacyCommunicationManager;
import com.vaadin.server.LegacyPaint;
@@ -581,7 +582,7 @@ public class Table extends AbstractSelect implements Action.Container,
private RowGenerator rowGenerator = null;
- private final Map<Field<?>, Property<?>> associatedProperties = new HashMap<Field<?>, Property<?>>();
+ private final Map<LegacyField<?>, Property<?>> associatedProperties = new HashMap<LegacyField<?>, Property<?>>();
private boolean painted = false;
@@ -2551,8 +2552,8 @@ public class Table extends AbstractSelect implements Action.Container,
* Also remove property data sources to unregister listeners keeping the
* fields in memory.
*/
- if (component instanceof Field) {
- Field<?> field = (Field<?>) component;
+ if (component instanceof LegacyField) {
+ LegacyField<?> field = (LegacyField<?>) component;
Property<?> associatedProperty = associatedProperties
.remove(component);
if (associatedProperty != null
@@ -4103,7 +4104,7 @@ public class Table extends AbstractSelect implements Action.Container,
protected Object getPropertyValue(Object rowId, Object colId,
Property property) {
if (isEditable() && fieldFactory != null) {
- final Field<?> f = fieldFactory.createField(
+ final LegacyField<?> f = fieldFactory.createField(
getContainerDataSource(), rowId, colId, this);
if (f != null) {
// Remember that we have made this association so we can remove
@@ -4119,7 +4120,7 @@ public class Table extends AbstractSelect implements Action.Container,
/**
* Binds an item property to a field generated by TableFieldFactory. The
* default behavior is to bind property straight to Field. If
* Property.Viewer type property (e.g. PropertyFormatter) is already set for
* field, the property is bound to that Property.Viewer.
*
@@ -4130,7 +4131,7 @@ public class Table extends AbstractSelect implements Action.Container,
* @since 6.7.3
*/
protected void bindPropertyToField(Object rowId, Object colId,
- Property property, Field field) {
+ Property property, LegacyField field) {
// check if field has a property that is Viewer set. In that case we
// expect developer has e.g. PropertyFormatter that he wishes to use and
// assign the property to the Viewer instead.
@@ -4780,7 +4781,7 @@ public class Table extends AbstractSelect implements Action.Container,
*
* The FieldFactory is only used if the Table is editable.
*
* @return TableFieldFactory used to create the Field instances.
* @see #isEditable
*/
public TableFieldFactory getTableFieldFactory() {
@@ -4790,7 +4791,7 @@ public class Table extends AbstractSelect implements Action.Container,
/**
* Is table editable.
*
* If table is editable a editor of type Field is created for each table
* cell. The assigned FieldFactory is used to create the instances.
*
* To provide custom editors for table cells create a class implementing the
@@ -4798,7 +4799,7 @@ public class Table extends AbstractSelect implements Action.Container,
* property to true.
*
* @return true if table is editable, false otherwise.
- * @see Field
+ * @see LegacyField
* @see FieldFactory
*
*/
@@ -4809,7 +4810,7 @@ public class Table extends AbstractSelect implements Action.Container,
/**
* Sets the editable property.
*
* If table is editable a editor of type Field is created for each table
* cell. The assigned FieldFactory is used to create the instances.
*
* To provide custom editors for table cells create a class implementing the
@@ -4818,7 +4819,7 @@ public class Table extends AbstractSelect implements Action.Container,
*
* @param editable
* true if table should be editable by user.
- * @see Field
+ * @see LegacyField
* @see FieldFactory
*
*/
@@ -4119,7 +4120,7 @@ public class Table extends AbstractSelect implements Action.Container,
/**
* Binds an item property to a field generated by TableFieldFactory. The
- * default behavior is to bind property straight to Field. If
+ * default behavior is to bind property straight to LegacyField. If
* Property.Viewer type property (e.g. PropertyFormatter) is already set for
* field, the property is bound to that Property.Viewer.
@@ -4780,7 +4781,7 @@ public class Table extends AbstractSelect implements Action.Container,
* The FieldFactory is only used if the Table is editable.
*
- * @return TableFieldFactory used to create the Field instances.
+ * @return TableFieldFactory used to create the LegacyField instances.
* @see #isEditable
*/
@@ -4790,7 +4791,7 @@ public class Table extends AbstractSelect implements Action.Container,
* Is table editable.
*
- * If table is editable a editor of type Field is created for each table
+ * If table is editable a editor of type LegacyField is created for each table
* cell. The assigned FieldFactory is used to create the instances.
*
@@ -4809,7 +4810,7 @@ public class Table extends AbstractSelect implements Action.Container,
* Sets the editable property.
*
- * If table is editable a editor of type Field is created for each table
+ * If table is editable a editor of type LegacyField is created for each table
* cell. The assigned FieldFactory is used to create the instances.
*